# Vantage client

This is a main class of interest for SDK users.

::: vantage_sdk.client
    options:
        show_root_heading: false
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_classes: true
        show_docstring_examples: true

::: vantage_sdk.model
    options:
        show_root_heading: false
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_classes: true
        show_docstring_examples: true
        show_submodules: true

::: vantage_sdk.core.management
    options:
        show_root_heading: false
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_classes: true
        show_docstring_examples: true
        show_submodules: true
        show_if_no_docstring: true

::: vantage_sdk.core.search
    options:
        show_root_heading: false
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_classes: true
        show_docstring_examples: true
        show_submodules: true
        show_if_no_docstring: true

# Exceptions

These exceptions have no documentation, as their names are self-explanatory. Left here for reference.

::: vantage_sdk.core.exceptions
    options:
        show_root_heading: false
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_classes: true
        show_docstring_examples: true
        show_submodules: true
        show_if_no_docstring: true

# Models generated from OpenAPI

This documentation is autogenerated from OpenAPI specification. It is added in here only for reference.

::: vantage_sdk.core.http.models
    options:
        show_root_heading: false
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_classes: true
        show_docstring_examples: true
        show_submodules: true
        show_if_no_docstring: false
